// 企业路由信息
import Layout from '@/layout/enterprise.vue'

const enterprise = [
  {
    path: '/recruit/enterprise',
    show: true,
    redirect: '/recruit/enterprise/talentPool',
  },
  {
    path: '/recruit/enterprise/talentPool',
    component: Layout,
    name: 'talentPool',
    meta: {
      title: '人才库',
      enName: 'Talent Pool',
      icon: 'mdi-account-multiple-outline'
    },
    children: [
      {
        path: '/recruit/enterprise/talentPool',
        show: true,
        component: () => import('@/views/recruit/enterprise/talentPool/index.vue')
      },
      {
        path: '/recruit/enterprise/talentPool/details/:id',
        show: true,
        component: () => import('@/views/recruit/enterprise/talentPool/components/details'),
        name: 'talentPoolDetails',
        meta: {
          title: '人才详情',
          hideSide: true
        }
      }
    ]
  },
  {
    path: '/recruit/enterprise/statistics',
    component: Layout,
    name: 'enterpriseStatistics',
    redirect: '/recruit/enterprise/statistics/overallAnalysis',
    meta: {
      title: '统计分析',
      enName: 'Statistics',
      icon: 'mdi-chart-arc'
    },
    children: [
      {
        path: '/recruit/enterprise/statistics/overallAnalysis',
        meta: {
          title: '整体分析',
          enName: 'Overall analysis'
        },
        component: () => import('@/views/recruit/enterprise/statistics/overallAnalysis.vue')
      }
    ]
  },
  {
    path: '/recruit/enterprise/position',
    component: Layout,
    name: 'jobManagement',
    meta: {
      title: '职位管理',
      enName: 'Job Management',
      icon: 'mdi-format-list-bulleted-square'
    },
    children: [
      {
        path: '/recruit/enterprise/position',
        meta: {
          title: '职位列表',
          enName: 'Job list'
        },
        component: () => import('@/views/recruit/enterprise/positionManagement/index.vue')
      },
      {
        path: '/recruit/enterprise/position/add',
        show: true,
        meta: {
          title: '新增职位'
        },
        component: () => import('@/views/recruit/enterprise/positionManagement/components/add.vue')
      },
      {
        path: '/recruit/enterprise/position/edit',
        show: true,
        meta: {
          title: '职位编辑'
        },
        component: () => import('@/views/recruit/enterprise/positionManagement/components/add.vue')
      },
      {
        path: '/recruit/enterprise/position/details/:id',
        show: true,
        meta: {
          title: '职位详情',
          hideSide: true
        },
        component: () => import('@/views/recruit/enterprise/positionManagement/components/details.vue')
      }
    ]
  },
  {
    path: '/recruit/enterprise/communication',
    component: Layout,
    name: 'Communication',
    meta: {
      title: '沟通',
      enName: 'Communication',
      icon: 'mdi-bell-outline'
    },
    children: [
      {
        path: '/recruit/enterprise/communication',
        show: true,
        component: () => import('@/views/recruit/enterprise/communication/index.vue')
      }
    ]
  },
  {
    path: '/recruit/enterprise/interview',
    component: Layout,
    name: 'interview',
    meta: {
      title: '面试',
      enName: 'interview',
      icon: 'mdi-account-multiple-check'
    },
    children: [
      {
        path: '/recruit/enterprise/interview',
        show: true,
        component: () => import('@/views/recruit/enterprise/interview/index.vue')
      }
    ]
  },
  {
    path: '/recruit/enterprise/personnelManagement',
    component: Layout,
    name: 'personnelManagement',
    meta: {
      title: '精英管理',
      enName: 'Meritocracy',
      icon: 'mdi-account-settings-outline'
    },
    children: [
      {
        path: '/recruit/enterprise/personnelManagement',
        show: true,
        component: () => import('@/views/recruit/enterprise/personnelManagement/index.vue')
      }
    ]
  },
  {
    path: '/recruit/enterprise/informationManagement',
    component: Layout,
    redirect: '/recruit/enterprise/informationManagement/informationSettings',
    name: 'informationManagement',
    meta: {
      title: '信息管理',
      enName: 'Information Management',
      icon: 'mdi-tune'
    },
    children: [
      {
        path: '/recruit/enterprise/informationManagement/informationSettings',
        meta: {
          title: '企业信息设置',
          isAdmin: true,
          enName: 'Enterprise Information Settings'
        },
        component: () => import('@/views/recruit/enterprise/informationManagement/informationSettings.vue')
      },
      {
        path: '/recruit/enterprise/informationSettings',
        meta: {
          title: '个人信息设置',
          enName: 'Personal information settings'
        },
        component: () => import('@/views/recruit/enterprise/informationSetting/index.vue')
      }
    ]
  },
  {
    path: '/recruit/enterprise/systemManagement',
    component: Layout,
    redirect: '/recruit/enterprise/systemManagement/userManagement',
    name: 'systemManagement',
    meta: {
      title: '系统管理',
      enName: 'system Management',
      icon: 'mdi-cog-outline',
      isAdmin: true // 企业管理员菜单
    },
    children: [
      {
        path: '/recruit/enterprise/systemManagement/userManagement',
        meta: {
          title: '用户管理',
          enName: 'User Management '
        },
        component: () => import('@/views/recruit/enterprise/systemManagement/userManagement/index.vue')
      }
    ]
  },
  {
    path: '/recruit/enterprise/memberCenter',
    component: Layout,
    redirect: '/recruit/enterprise/memberCenter/myAccount',
    name: 'enterpriseMemberCenter',
    meta: {
      title: '会员中心',
      enName: 'system Management',
      icon: 'mdi-account',
      // isAdmin: true // 企业管理员菜单
    },
    children: [
      {
        path: '/recruit/enterprise/memberCenter/myAccount',
        meta: {
          title: '我的会员',
          enName: 'My Account '
        },
        component: () => import('@/views/recruit/enterprise/memberCenter/myAccount/index.vue')
      },
      {
        path: '/recruit/enterprise/memberCenter/myPoints',
        meta: {
          title: '我的积分',
          enName: 'My Points '
        },
        component: () => import('@/views/recruit/enterprise/memberCenter/myPoints/index.vue')
      }
    ]
  },
  {
    path: '/recruit/enterprise/enterpriseCenter',
    component: Layout,
    name: 'enterpriseCenter',
    show: true,
    redirect: '/recruit/enterprise/enterpriseCenter',
    meta: {
      title: '企业中心'
    },
    children: [
      {
        path: '/recruit/enterprise/enterpriseCenter',
        show: true,
        component: () => import('@/views/recruit/enterprise/enterpriseCenter/index.vue'),
        meta: {
          title: '企业中心',
          hideSide: true
        }
      }
    ]
  },
  {
    path: '/recruit/enterprise/purchasePackage',
    component: Layout,
    name: 'enterprisePurchasePackage',
    show: true,
    meta: {
      title: '购买套餐',
    },
    children: [
      {
        path: '/recruit/enterprise/purchasePackage',
        component: () => import('@/views/recruit/enterprise/purchasePackage/index'),
        meta: {
          title: '购买套餐',
          hideSide: true
        },
      }
    ]
  },
  // {
  //   path: '/enterprise/myAccount',
  //   component: Layout,
  //   name: 'enterpriseMyAccount',
  //   show: true,
  //   meta: {
  //     title: '我的账户',
  //   },
  //   children: [
  //     {
  //       path: '/enterprise/myAccount',
  //       component: () => import('@/views/enterprise/myAccount/index'),
  //       meta: {
  //         title: '我的账户',
  //         hideSide: false
  //       },
  //     }
  //   ]
  // },
]
export default enterprise